/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                  GRADO TERMINAL DE BACHILLERATO (Excale 12)
/*
/*                          **** CONTEXTO ****
/*
/*                     Ciclo escolar evaluado: 2009 - 2010
/*_____________________________________________________________________________
/*
/*
/*       PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE CONTEXTO
/*                               EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale12_2010_Alum_Cuest.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale12_2010_Alum_Cuest.txt
/*         as como el archivo Excale12_2010_Alum_Cuest.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale12_2010_Alum_Cuest.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale12_2010_Alum_Cuest.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 23 DE NOVIEMBRE DEL 2010
/*
/*  ****************************************************************************/

LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale12_2010_Alum_Cuest.TXT";

PROC FORMAT;
     VALUE id_entF     1         = "Aguascalientes"
                       2         = "Baja California"
                       3         = "Baja California Sur"
                       4         = "Campeche"
                       5         = "Coahuila"
                       6         = "Colima"
                       7         = "Chiapas"
                       8         = "Chihuahua"
                       9         = "Distrito Federal"
                       10        = "Durango"
                       11        = "Guanajuato"
                       12        = "Guerrero"
                       13        = "Hidalgo"
                       14        = "Jalisco"
                       15        = "Mxico"
                       16        = "Michoacn"
                       17        = "Morelos"
                       18        = "Nayarit"
                       19        = "Nuevo Len"
                       20        = "Oaxaca"
                       21        = "Puebla"
                       22        = "Quertaro"
                       23        = "Quintana Roo"
                       24        = "San Luis Potos"
                       25        = "Sinaloa"
                       26        = "Sonora"
                       27        = "Tabasco"
                       28        = "Tamaulipas"
                       29        = "Tlaxcala"
                       30        = "Veracruz"
                       31        = "Yucatn"
                       32        = "Zacatecas";
     VALUE id_modF     10        = "Bachillerato General"
                       11        = "Bachillerato Tecnolgico"
                       12        = "Profesional Tcnico";
     VALUE $modF       "BG"      = "Bachillerato General"
                       "BT"      = "Bachillerato Tecnolgico"
                       "PT"      = "Profesional Tcnico";
     VALUE ESTRATOF    111       = "BG_Autnomo<34"
                       112       = "BG_Autnomo_34-100"
                       113       = "BG_Autnomo_101-500"
                       114       = "BG_Autnomo>500"
                       121       = "BG_COBACH<34"
                       122       = "BG_COBACH_34-100"
                       123       = "BG_COBACH_101-500"
                       124       = "BG_COBACH>500"
                       131       = "BG_otros<34"
                       132       = "BG_otros_34-100"
                       133       = "BG_otros_101-500"
                       134       = "BG_otros>500"
                       141       = "BG_privadas<34"
                       142       = "BG_privadas_34-100"
                       143       = "BG_privadas_101-500"
                       144       = "BG_privadas>500"
                       211       = "BT_CBTIS<34"
                       212       = "BT_CBTIS_34-100"
                       213       = "BT_CBTIS_101-500"
                       214       = "BT_CBTIS>500"
                       221       = "BT_otros<34"
                       222       = "BT_otros_34-100"
                       223       = "BT_otros_101-500"
                       224       = "BT_otros>500"
                       311       = "PT_CONALEP<34"
                       312       = "PT_CONALEP_34-100"
                       313       = "PT_CONALEP_101-500"
                       314       = "PT_CONALEP>500"
                       321       = "PT_otros<34"
                       322       = "PT_otros_34-100"
                       323       = "PT_otros_101-500"
                       324       = "PT_otros>500";
     VALUE sexoF       1         = "Hombre"
                       2         = "Mujer"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE edad_acF    8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AB001F      0         = "Espaol"
                       1         = "Una lengua indgena (nhuatl, maya, purpecha, mixteco, otom, etc.)"
                       2         = "Una lengua extranjera (francs, ingls, alemn, etc.)"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AB2_3F      0         = "Espaol"
                       1         = "Una lengua indgena (nhuatl, maya, purpecha, mixteco, otom, etc.)"
                       2         = "Una lengua extranjera (francs, ingls, alemn, etc.)"
                       3         = "No s"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AB004F      0         = "No s/no tengo pap"
                       1         = "No fue a la escuela"
                       2         = "Primaria incompleta"
                       3         = "Primaria"
                       4         = "Secundaria"
                       5         = "Bachillerato"
                       6         = "Carrera tcnica"
                       7         = "Licenciatura o posgrado"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AB005F      0         = "No s/no tengo mam"
                       1         = "No fue a la escuela"
                       2         = "Primaria incompleta"
                       3         = "Primaria"
                       4         = "Secundaria"
                       5         = "Bachillerato"
                       6         = "Carrera tcnica"
                       7         = "Licenciatura o posgrado"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AB006F      2         = "S toman en cuenta mi opinin"
                       1         = "Opino pero no me toman en cuenta"
                       0         = "Evito dar mi opinin"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AB007F      0         = "De 0 a 3 focos"
                       1         = "Entre 4 y 5"
                       2         = "Entre 6 y 7"
                       3         = "Entre 8 y 9"
                       4         = "Entre 10 y 15"
                       5         = "Entre 16 y 25"
                       6         = "Ms de 26"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AB8_12F     1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE AB013F      0         = "Ninguno"
                       1         = "1 a 10 libros"
                       2         = "11 a 25"
                       3         = "26 a 50"
                       4         = "51 a 100"
                       5         = "Ms de 100"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB014F     0         = "S"
                       1         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB015F     1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB016F     0         = "No trabajo"
                       1         = "10 horas o menos"
                       2         = "De 11 a 20"
                       3         = "De 21 a 30"
                       4         = "De 31 a 40"
                       5         = "Ms de 40"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB017F     0         = "No trabajo"
                       1         = "Trabajo pero no recibo pago"
                       2         = "Trabajo pero no aporto"
                       3         = "S aporto"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB018F     1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB019F     0         = "No participo en ninguna actividad"
                       1         = "Entre 1 y 5 horas"
                       2         = "Entre 6 y 10"
                       3         = "Entre 11 y 20"
                       4         = "Ms de 20"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB020F     1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB021F     0         = "No lo uso"
                       1         = "Al menos un da"
                       2         = "2  3"
                       3         = "4  5"
                       4         = "6  7"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB022F     0         = "No hago tarea ni estudio"
                       1         = "Al menos un da"
                       2         = "2  3"
                       3         = "4  5"
                       4         = "6  7"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB023F     0         = "No hago tareas ni estudio"
                       1         = "Al menos una hora"
                       2         = "2"
                       3         = "3"
                       4         = "4 o ms"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB024F     0         = "No leo"
                       1         = "5 horas o menos"
                       2         = "Entre 6 y 10"
                       3         = "Entre 11 y 15"
                       4         = "Entre 16 y 20"
                       5         = "Ms de 20"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB25_30F   0         = "Casi nunca"
                       1         = "Pocas veces"
                       2         = "Frecuentemente"
                       3         = "Muy frecuentemente"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB031F     1         = "Secundaria pblica general"
                       2         = "Secundaria pblica tcnica"
                       3         = "Telesecundaria"
                       4         = "Secundaria privada"
                       5         = "Secundaria abierta o a distancia"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB032F     5         = "14 aos o menos"
                       4         = "15"
                       3         = "16"
                       2         = "17"
                       1         = "18 o ms"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB033F     0         = "No cuento con beca"
                       1         = "Beca del programa 'Oportunidades' "
                       2         = "Otro tipo de beca"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB034F     2         = "S"
                       1         = "No"
                       0         = "No lo s"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB035F     0         = "Nadie"
                       1         = "Pap"
                       2         = "Mam"
                       3         = "Hermanos"
                       4         = "Otros adultos"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB036F     0         = "diferente a las opciones que eleg"
                       1         = "la nica opcin que tena"
                       2         = "una de las opciones que eleg"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB037F     4         = "No he faltado"
                       3         = "1 da"
                       2         = "2  3"
                       1         = "4  5"
                       0         = "Ms de 5"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB038F     0         = "No hago tarea"
                       1         = "En casa"
                       2         = "En la escuela"
                       3         = "En el trabajo"
                       4         = "En otro lugar"
                       5         = "No dejan tarea"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB039F     5         = "Entre 9.5 y 10"
                       4         = "Entre 8.5 y 9.4"
                       3         = "Entre 7.5 y 8.4"
                       2         = "Entre 6.5 y 7.4"
                       1         = "Entre 6.0 y 6.4"
                       0         = "Menos de 6.0"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB040F     6         = "Ninguna"
                       5         = "1 materia"
                       4         = "2  3"
                       3         = "4  5"
                       2         = "6  7"
                       1         = "8  9"
                       0         = "Ms de 9"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB041F     5         = "No he reprobado"
                       4         = "Lenguaje y Comunicacin (Espaol, Lectura y redaccin, Literatura, Expresin oral o escrita, etc.)"
                       3         = "Matemticas (lgebra, Clculo, Estadstica, Probabilidad, Lgica, etc.)"
                       2         = "Ciencias Sociales (Filosofa, Esttica, Psicologa, Derecho, Historia, Valores, etc.)"
                       1         = "Ciencias Experimentales (Fsica, Qumica, Biologa, etc.)"
                       0         = "Tecnologas de la Informacin y la Comunicacin (Computacin, Informtica, etc.)"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB042F     0         = "no recibo asesoras o tutoras"
                       1         = "preparar exmenes finales"
                       2         = "reforzar el contenido de un tema especfico"
                       3         = "resolver dudas de la clase"
                       4         = "resolver problemas personales"
                       5         = "orientacin vocacional"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB043F     0         = "No he recibido asesoras o tutoras"
                       1         = "Nada tiles"
                       2         = "Poco tiles"
                       3         = "Muy tiles"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB044F     0         = "No me gusta"
                       1         = "Poco"
                       2         = "Regular"
                       3         = "Mucho"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB045F     4         = "Para estar con los amigos"
                       3         = "Para continuar con mis estudios"
                       2         = "Para cumplir con mi obligacin"
                       1         = "Para encontrar mejores opciones de trabajo"
                       0         = "Otra"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB046F     1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB047F     2         = "S toman en cuenta mi opinin"
                       1         = "Opino pero no me toman en cuenta"
                       0         = "Evito dar mi opinin"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB48_49F   2         = "S"
                       1         = "No"
                       0         = "No ha votaciones"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB050F     1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB051F     3         = "S lo conozco"
                       2         = "No lo conozco, pero s que existe"
                       1         = "No s si existe"
                       0         = "No existe"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB052F     0         = "Trabajo"
                       1         = "Embarazo"
                       2         = "Falta de recursos"
                       3         = "Reprobar materias"
                       4         = "Problemas familiares"
                       5         = "Falta de inters en la escuela"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
      VALUE AB53_68F   0         = "Casi nunca"
                       1         = "Pocas veces"
                       2         = "Frecuentemente"
                       3         = "Muy frecuentemente"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";

RUN;



DATA INEE.Excale12_2010_Alum_Cuest;
   LENGTH
       NACIONAL           3
       ESCUELA            4
       ID_ENT             3
       NOM_ENT            $19
       ID_MOD             3
       MOD                $4
       ESTRATO            3
       ALUMNO             6
       ID_INSTR           $16
       SEXO               3
       EDAD_AC            3
       W_ALU              8
       AB001              3
       AB002              3
       AB003              3
       AB004              3
       AB005              3
       AB006              3
       AB007              3
       AB008              3
       AB009              3
       AB010              3
       AB011              3
       AB012              3
       AB013              3
       AB014              3
       AB015              3
       AB016              3
       AB017              3
       AB018              3
       AB019              3
       AB020              3
       AB021              3
       AB022              3
       AB023              3
       AB024              3
       AB025              3
       AB026              3
       AB027              3
       AB028              3
       AB029              3
       AB030              3
       AB031              3
       AB032              3
       AB033              3
       AB034              3
       AB035              3
       AB036              3
       AB037              3
       AB038              3
       AB039              3
       AB040              3
       AB041              3
       AB042              3
       AB043              3
       AB044              3
       AB045              3
       AB046              3
       AB047              3
       AB048              3
       AB049              3
       AB050              3
       AB051              3
       AB052              3
       AB053              3
       AB054              3
       AB055              3
       AB056              3
       AB057              3
       AB058              3
       AB059              3
       AB060              3
       AB061              3
       AB062              3
       AB063              3
       AB064              3
       AB065              3
       AB066              3
       AB067              3
       AB068              3
       WVARSTRR           3
       W_FSTR1            8
       W_FSTR2            8
       W_FSTR3            8
       W_FSTR4            8
       W_FSTR5            8
       W_FSTR6            8
       W_FSTR7            8
       W_FSTR8            8
       W_FSTR9            8
       W_FSTR10           8
       W_FSTR11           8
       W_FSTR12           8
       W_FSTR13           8
       W_FSTR14           8
       W_FSTR15           8
       W_FSTR16           8
       W_FSTR17           8
       W_FSTR18           8
       W_FSTR19           8
       W_FSTR20           8
       W_FSTR21           8
       W_FSTR22           8
       W_FSTR23           8
       W_FSTR24           8
       W_FSTR25           8
       W_FSTR26           8
       W_FSTR27           8
       W_FSTR28           8
       W_FSTR29           8
       W_FSTR30           8
       W_FSTR31           8
       W_FSTR32           8
       W_FSTR33           8
       W_FSTR34           8
       W_FSTR35           8
       W_FSTR36           8
       W_FSTR37           8
       W_FSTR38           8
       W_FSTR39           8
       W_FSTR40           8
       W_FSTR41           8
       W_FSTR42           8
       W_FSTR43           8
       W_FSTR44           8
       W_FSTR45           8
       W_FSTR46           8
       W_FSTR47           8
       W_FSTR48           8
       W_FSTR49           8
       W_FSTR50           8
       W_FSTR51           8
       W_FSTR52           8
       W_FSTR53           8
       W_FSTR54           8
       W_FSTR55           8
       W_FSTR56           8
       W_FSTR57           8
       W_FSTR58           8
       W_FSTR59           8
       W_FSTR60           8
       W_FSTR61           8
       W_FSTR62           8
       W_FSTR63           8
       W_FSTR64           8
       W_FSTR65           8
       W_FSTR66           8
       W_FSTR67           8
       W_FSTR68           8
       W_FSTR69           8
       W_FSTR70           8
       W_FSTR71           8
       W_FSTR72           8
       W_FSTR73           8
       W_FSTR74           8
       W_FSTR75           8
       W_FSTR76           8
       W_FSTR77           8
       W_FSTR78           8
       W_FSTR79           8
       W_FSTR80           8
       W_FSTR81           8
       W_FSTR82           8
       W_FSTR83           8
       W_FSTR84           8
       W_FSTR85           8
       W_FSTR86           8
       W_FSTR87           8
       W_FSTR88           8
       W_FSTR89           8
       W_FSTR90           8
       W_FSTR91           8
       W_FSTR92           8
       W_FSTR93           8
       W_FSTR94           8
       W_FSTR95           8
       W_FSTR96           8
       W_FSTR97           8
       W_FSTR98           8
       W_FSTR99           8
       W_FSTR100          8
       W_FSTR101          8
       W_FSTR102          8
       W_FSTR103          8
       W_FSTR104          8
       W_FSTR105          8
       W_FSTR106          8
       W_FSTR107          8
       W_FSTR108          8
       W_FSTR109          8
       W_FSTR110          8
       W_FSTR111          8
       W_FSTR112          8
       W_FSTR113          8
       W_FSTR114          8
       W_FSTR115          8
       W_FSTR116          8
       W_FSTR117          8
       W_FSTR118          8
       W_FSTR119          8
       W_FSTR120          8
       W_FSTR121          8
       W_FSTR122          8
       W_FSTR123          8
       W_FSTR124          8
       W_FSTR125          8
       W_FSTR126          8
       W_FSTR127          8
       W_FSTR128          8
 ;

INFILE alum MISSOVER LINESIZE = 1553;
   INPUT
        NACIONAL           1 - 1
        ESCUELA            2 - 5
        ID_ENT             6 - 7
        NOM_ENT            8 - 26
        ID_MOD            27 - 28
        MOD               29 - 32
        ESTRATO           33 - 39
        ALUMNO            40 - 45
        ID_INSTR          46 - 61
        SEXO              62 - 62
        EDAD_AC           63 - 63
        W_ALU             64 - 74
        AB001             75 - 75
        AB002             76 - 76
        AB003             77 - 77
        AB004             78 - 78
        AB005             79 - 79
        AB006             80 - 80
        AB007             81 - 81
        AB008             82 - 82
        AB009             83 - 83
        AB010             84 - 84
        AB011             85 - 85
        AB012             86 - 86
        AB013             87 - 87
        AB014             88 - 88
        AB015             89 - 89
        AB016             90 - 90
        AB017             91 - 91
        AB018             92 - 92
        AB019             93 - 93
        AB020             94 - 94
        AB021             95 - 95
        AB022             96 - 96
        AB023             97 - 97
        AB024             98 - 98
        AB025             99 - 99
        AB026            100 - 100
        AB027            101 - 101
        AB028            102 - 102
        AB029            103 - 103
        AB030            104 - 104
        AB031            105 - 105
        AB032            106 - 106
        AB033            107 - 107
        AB034            108 - 108
        AB035            109 - 109
        AB036            110 - 110
        AB037            111 - 111
        AB038            112 - 112
        AB039            113 - 113
        AB040            114 - 114
        AB041            115 - 115
        AB042            116 - 116
        AB043            117 - 117
        AB044            118 - 118
        AB045            119 - 119
        AB046            120 - 120
        AB047            121 - 121
        AB048            122 - 122
        AB049            123 - 123
        AB050            124 - 124
        AB051            125 - 125
        AB052            126 - 126
        AB053            127 - 127
        AB054            128 - 128
        AB055            129 - 129
        AB056            130 - 130
        AB057            131 - 131
        AB058            132 - 132
        AB059            133 - 133
        AB060            134 - 134
        AB061            135 - 135
        AB062            136 - 136
        AB063            137 - 137
        AB064            138 - 138
        AB065            139 - 139
        AB066            140 - 140
        AB067            141 - 141
        AB068            142 - 142
        WVARSTRR         143 - 145
        W_FSTR1          146 - 156
        W_FSTR2          157 - 167
        W_FSTR3          168 - 178
        W_FSTR4          179 - 189
        W_FSTR5          190 - 200
        W_FSTR6          201 - 211
        W_FSTR7          212 - 222
        W_FSTR8          223 - 233
        W_FSTR9          234 - 244
        W_FSTR10         245 - 255
        W_FSTR11         256 - 266
        W_FSTR12         267 - 277
        W_FSTR13         278 - 288
        W_FSTR14         289 - 299
        W_FSTR15         300 - 310
        W_FSTR16         311 - 321
        W_FSTR17         322 - 332
        W_FSTR18         333 - 343
        W_FSTR19         344 - 354
        W_FSTR20         355 - 365
        W_FSTR21         366 - 376
        W_FSTR22         377 - 387
        W_FSTR23         388 - 398
        W_FSTR24         399 - 409
        W_FSTR25         410 - 420
        W_FSTR26         421 - 431
        W_FSTR27         432 - 442
        W_FSTR28         443 - 453
        W_FSTR29         454 - 464
        W_FSTR30         465 - 475
        W_FSTR31         476 - 486
        W_FSTR32         487 - 497
        W_FSTR33         498 - 508
        W_FSTR34         509 - 519
        W_FSTR35         520 - 530
        W_FSTR36         531 - 541
        W_FSTR37         542 - 552
        W_FSTR38         553 - 563
        W_FSTR39         564 - 574
        W_FSTR40         575 - 585
        W_FSTR41         586 - 596
        W_FSTR42         597 - 607
        W_FSTR43         608 - 618
        W_FSTR44         619 - 629
        W_FSTR45         630 - 640
        W_FSTR46         641 - 651
        W_FSTR47         652 - 662
        W_FSTR48         663 - 673
        W_FSTR49         674 - 684
        W_FSTR50         685 - 695
        W_FSTR51         696 - 706
        W_FSTR52         707 - 717
        W_FSTR53         718 - 728
        W_FSTR54         729 - 739
        W_FSTR55         740 - 750
        W_FSTR56         751 - 761
        W_FSTR57         762 - 772
        W_FSTR58         773 - 783
        W_FSTR59         784 - 794
        W_FSTR60         795 - 805
        W_FSTR61         806 - 816
        W_FSTR62         817 - 827
        W_FSTR63         828 - 838
        W_FSTR64         839 - 849
        W_FSTR65         850 - 860
        W_FSTR66         861 - 871
        W_FSTR67         872 - 882
        W_FSTR68         883 - 893
        W_FSTR69         894 - 904
        W_FSTR70         905 - 915
        W_FSTR71         916 - 926
        W_FSTR72         927 - 937
        W_FSTR73         938 - 948
        W_FSTR74         949 - 959
        W_FSTR75         960 - 970
        W_FSTR76         971 - 981
        W_FSTR77         982 - 992
        W_FSTR78         993 - 1003
        W_FSTR79        1004 - 1014
        W_FSTR80        1015 - 1025
        W_FSTR81        1026 - 1036
        W_FSTR82        1037 - 1047
        W_FSTR83        1048 - 1058
        W_FSTR84        1059 - 1069
        W_FSTR85        1070 - 1080
        W_FSTR86        1081 - 1091
        W_FSTR87        1092 - 1102
        W_FSTR88        1103 - 1113
        W_FSTR89        1114 - 1124
        W_FSTR90        1125 - 1135
        W_FSTR91        1136 - 1146
        W_FSTR92        1147 - 1157
        W_FSTR93        1158 - 1168
        W_FSTR94        1169 - 1179
        W_FSTR95        1180 - 1190
        W_FSTR96        1191 - 1201
        W_FSTR97        1202 - 1212
        W_FSTR98        1213 - 1223
        W_FSTR99        1224 - 1234
        W_FSTR100       1235 - 1245
        W_FSTR101       1246 - 1256
        W_FSTR102       1257 - 1267
        W_FSTR103       1268 - 1278
        W_FSTR104       1279 - 1289
        W_FSTR105       1290 - 1300
        W_FSTR106       1301 - 1311
        W_FSTR107       1312 - 1322
        W_FSTR108       1323 - 1333
        W_FSTR109       1334 - 1344
        W_FSTR110       1345 - 1355
        W_FSTR111       1356 - 1366
        W_FSTR112       1367 - 1377
        W_FSTR113       1378 - 1388
        W_FSTR114       1389 - 1399
        W_FSTR115       1400 - 1410
        W_FSTR116       1411 - 1421
        W_FSTR117       1422 - 1432
        W_FSTR118       1433 - 1443
        W_FSTR119       1444 - 1454
        W_FSTR120       1455 - 1465
        W_FSTR121       1466 - 1476
        W_FSTR122       1477 - 1487
        W_FSTR123       1488 - 1498
        W_FSTR124       1499 - 1509
        W_FSTR125       1510 - 1520
        W_FSTR126       1521 - 1531
        W_FSTR127       1532 - 1542
        W_FSTR128       1543 - 1553
;

   LABEL
      NACIONAL     = "Variable auxiliar para obtener promedios nacionales"
      ESCUELA      = "Identificador de la escuela"
      ID_ENT       = "Entidad federativa (identificador numrico)"
      NOM_ENT      = "Entidad federativa"
      ID_MOD       = "Estrato escolar o Modalidad educativa (identificador numrico)"
      MOD          = "Estrato escolar o Modalidad educativa"
      ESTRATO      = "Estrato de muestreo"
      ALUMNO       = "Identificador del alumno"
      ID_INSTR     = "Identificador del cuadernillo de examen"
      SEXO         = "Sexo del alumno"
      EDAD_AC      = "Edad en aos cumplidos (al momento de la aplicacin)"
      W_ALU        = "Peso muestral o ponderador del alumno"
      AB001        = "Qu lengua aprendiste a hablar primero?"
      AB002        = "Qu lengua aprendi a hablar primero tu pap?"
      AB003        = "Qu lengua aprendi a hablar primero tu mam?"
      AB004        = "Cul es el nivel mximo que estudi tu pap?"
      AB005        = "Cul es el nivel mximo que estudi tu mam?"
      AB006        = "Tu familia considera tu opinin para tomar decisiones que te afectan?"
      AB007        = "Cuntos focos hay en tu casa?"
      AB008        = "Cules de los siguientes bienes y servicios hay en tu casa? Agua entubada todos los das"
      AB009        = "Cules de los siguientes bienes y servicios hay en tu casa? Automvil"
      AB010        = "Cules de los siguientes bienes y servicios hay en tu casa? Televisin de paga (por cable o satlite)"
      AB011        = "Cules de los siguientes bienes y servicios hay en tu casa? Computadora"
      AB012        = "Cules de los siguientes bienes y servicios hay en tu casa? Internet"
      AB013        = "Aproximadamente, cuntos libros hay en tu casa? (No incluyas revistas, ni peridicos, ni tus libros escolares)"
      AB014        = "En tu casa, duermen ms de tres personas en un mismo cuarto?"
      AB015        = "En tu casa, cuentas con un espacio adecuado para estudiar?"
      AB016        = "Cuntas horas a la semana trabajas?"
      AB017        = "Del pago que recibes, aportas para los gastos de tu casa?"
      AB018        = "Fuera de la escuela, participas en alguna actividad cultural o deportiva?"
      AB019        = "Cuntas horas a la semana le dedicas a esas actividades culturales o deportivas?"
      AB020        = "Por tu iniciativa e inters propio, participas en discusiones o plticas organizadas sobre problemas sociales actuales?"
      AB021        = "Cuntos das a la semana utilizas el correo electrnico?"
      AB022        = "Aproximadamente, cuntos das a la semana haces tarea o estudias?"
      AB023        = "En general, cuntas horas al da dedicas a estudiar o hacer tarea fuera de la escuela?"
      AB024        = "En la ltima semana, cuntas horas has dedicado a la lectura por tu iniciativa e inters propios?"
      AB025        = "Habitualmente, en una semana, con qu frecuencia lees peridicos... por necesidad escolar?"
      AB026        = "Habitualmente, en una semana, con qu frecuencia lees peridicos... por inters propio?"
      AB027        = "Habitualmente, en una semana, con qu frecuencia lees revistas de divulgacin cientfica, de salud, de poltica, economa o cultura (historia, literatura, etc.)... por necesidad escolar?"
      AB028        = "Habitualmente, en una semana, con qu frecuencia lees revistas de divulgacin cientfica, de salud, de poltica, economa o cultura (historia, literatura, etc.)... por inters propio?"
      AB029        = "Habitualmente, en una semana, con qu frecuencia lees libros de literatura (cuentos, novelas, poemas, etc.), o de ciencia, historia, etc... por necesidad escolar?"
      AB030        = "Habitualmente, en una semana, con qu frecuencia lees libros de literatura (cuentos, novelas, poemas, etc.), o de ciencia, historia, etc... por inters propio?"
      AB031        = "En qu tipo de escuela cursaste toda o la mayor parte de la secundaria?"
      AB032        = "A qu edad ingresaste al bachillerato?"
      AB033        = "Actualmente, cuentas con algn tipo de beca para estudiar?"
      AB034        = "Al trmino del bachillerato, tienes pensado seguir estudiando?"
      AB035        = "Principalmente, quin se mantiene al pendiente de tu situacin acadmica?"
      AB036        = "La escuela en la que estudias fue..."
      AB037        = "En las ltimas dos semanas, cuntos das faltaste a la escuela?"
      AB038        = "En qu lugar acostumbras a hacer la tarea?"
      AB039        = "Hasta el momento, cul es tu promedio de calificaciones en el bachillerato?"
      AB040        = "En lo que llevas del bachillerato, cuntas materias has reprobado en total?"
      AB041        = "En cul de las siguientes reas tienes ms materias reprobadas?"
      AB042        = "Las asesoras o tutoras que te da la escuela son principalmente para..."
      AB043        = "En este ciclo escolar, qu tan tiles han sido las asesoras o tutoras que has recibido?"
      AB044        = "Qu tanto te gusta estudiar en esta escuela?"
      AB045        = "Cul es la razn principal por la que asistes a la escuela?"
      AB046        = "Diras que, en general, el personal de tu escuela respeta que los estudiantes expresen su opinin?"
      AB047        = "En tu escuela, consideran tu opinin para tomar decisiones que te afectan?"
      AB048        = "Participas en votaciones para elegir representantes estudiantiles?"
      AB049        = "Diras que en tu escuela se respetan las decisiones tomadas por las asociaciones estudiantiles?"
      AB050        = "Diras que, en general, el personal de tu escuela respeta tu forma de vestir o peinar?"
      AB051        = "Conoces el reglamento escolar?"
      AB052        = "Cul consideras que es la principal razn por la que un estudiante de tu edad abandona la escuela?"
      AB053        = "Qu tan seguido faltan tus maestros a clases?"
      AB054        = "Tus maestros empiezan sus clases puntualmente?"
      AB055        = "Al leer en clase, tus maestros dan tiempo para discutir y comentar los textos ledos?"
      AB056        = "Al leer en clase, tus maestros te ayudan a identificar las ideas principales del texto ledo?"
      AB057        = "En la ltima semana, tus maestros te han pedido escribir textos como resmenes, ensayos, reportes de investigacin, etc.?"
      AB058        = "Tus maestros hacen comentarios a tus escritos, sugirindote cmo mejorarlos?"
      AB059        = "Consideras que tus profesores del rea de Matemticas (pueden haberte dado materias como lgebra, Clculo, Estadstica, Matemticas, Probabilidad, Lgica, etc.), en general... explican claramente los contenidos de la materia"
      AB060        = "Consideras que tus profesores del rea de Matemticas (pueden haberte dado materias como lgebra, Clculo, Estadstica, Matemticas, Probabilidad, Lgica, etc.), en general... proponen ejercicios aplicables a situaciones de la vida"
      AB061        = "Consideras que tus profesores del rea de Matemticas (pueden haberte dado materias como lgebra, Clculo, Estadstica, Matemticas, Probabilidad, Lgica, etc.), en general... ayudan a resolver dudas de cursos anteriores"
      AB062        = "Consideras que tus profesores del rea de Matemticas (pueden haberte dado materias como lgebra, Clculo, Estadstica, Matemticas, Probabilidad, Lgica, etc.), en general... utilizan diferentes materiales para apoyar tu aprendizaje"
      AB063        = "Consideras que tus profesores del rea de Matemticas (pueden haberte dado materias como lgebra, Clculo, Estadstica, Matemticas, Probabilidad, Lgica, etc.), en general... promueven en clase el pensamiento crtico; reflexin, anlisis de los contenidos"
      AB064        = "Consideras que tus profesores del rea de Lenguaje y Comunicacin (pueden haberte dado materias como Espaol, Expresin oral y escrita, Lectura y redaccin, Literatura, etc.), en general... explican claramente los contenidos de la materia"
      AB065        = "Consideras que tus profesores del rea de Lenguaje y Comunicacin (pueden haberte dado materias como Espaol, Expresin oral y escrita, Lectura y redaccin, Literatura, etc.), en general... proponen ejercicios aplicables a situaciones de la vida"
      AB066        = "Consideras que tus profesores del rea de Lenguaje y Comunicacin (pueden haberte dado materias como Espaol, Expresin oral y escrita, Lectura y redaccin, Literatura, etc.), en general... ayudan a resolver dudas de cursos anteriores"
      AB067        = "Consideras que tus profesores del rea de Lenguaje y Comunicacin (pueden haberte dado materias como Espaol, Expresin oral y escrita, Lectura y redaccin, Literatura, etc.), en general... utilizan diferentes materiales para apoyar su aprendizaje"
      AB068        = "Consideras que tus profesores del rea de Lenguaje y Comunicacin (pueden haberte dado materias como Espaol, Expresin oral y escrita, Lectura y redaccin, Literatura, etc.), en general... promueven en clase el pensamiento crtico; reflexin, anlisis"
      WVARSTRR     = "Identificador del pseudoestrato (1 a 128) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
      W_FSTR1      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR2      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR3      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR4      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR5      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR6      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR7      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR8      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR9      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR10     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR11     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR12     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR13     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR14     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR15     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR16     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR17     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR18     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR19     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR20     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR21     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR22     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR23     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR24     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR25     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR26     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR27     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR28     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR29     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR30     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR31     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR32     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR33     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR34     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR35     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR36     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR37     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR38     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR39     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR40     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR41     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR42     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR43     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR44     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR45     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR46     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR47     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR48     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR49     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR50     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR51     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR52     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR53     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR54     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR55     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR56     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR57     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR58     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR59     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR60     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR61     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR62     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR63     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR64     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR65     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR66     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR67     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR68     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR69     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR70     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR71     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR72     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR73     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR74     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR75     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR76     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR77     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR78     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR79     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR80     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR81     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR82     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR83     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR84     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR85     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR86     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR87     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR88     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR89     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR90     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR91     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR92     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR93     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR94     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR95     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR96     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR97     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR98     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR99     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR100    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR101    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR102    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR103    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR104    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR105    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR106    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR107    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR108    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR109    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR110    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR111    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR112    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR113    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR114    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR115    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR116    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR117    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR118    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR119    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR120    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR121    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR122    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR123    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR124    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR125    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR126    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR127    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR128    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
;

   FORMAT
       nacional           1.
       escuela            4.
       id_ent             id_entF.
       nom_ent            $char19.
       id_mod             id_modF.
       mod                $modF.
       estrato            EstratoF.
       alumno             5.
       id_instr           $char16.
       sexo               sexoF.
       edad_ac            edad_acF.
       AB001              AB001F.
       AB002              AB2_3F.
       AB003              AB2_3F.
       AB004              AB004F.
       AB005              AB005F.
       AB006              AB006F.
       AB007              AB007F.
       AB008              AB8_12F.
       AB009              AB8_12F.
       AB010              AB8_12F.
       AB011              AB8_12F.
       AB012              AB8_12F.
       AB013              AB013F.
       AB014              AB014F.
       AB015              AB015F.
       AB016              AB016F.
       AB017              AB017F.
       AB018              AB018F.
       AB019              AB019F.
       AB020              AB020F.
       AB021              AB021F.
       AB022              AB022F.
       AB023              AB023F.
       AB024              AB024F.
       AB025              AB25_30F.
       AB026              AB25_30F.
       AB027              AB25_30F.
       AB028              AB25_30F.
       AB029              AB25_30F.
       AB030              AB25_30F.
       AB031              AB031F.
       AB032              AB032F.
       AB033              AB033F.
       AB034              AB034F.
       AB035              AB035F.
       AB036              AB036F.
       AB037              AB037F.
       AB038              AB038F.
       AB039              AB039F.
       AB040              AB040F.
       AB041              AB041F.
       AB042              AB042F.
       AB043              AB043F.
       AB044              AB044F.
       AB045              AB045F.
       AB046              AB046F.
       AB047              AB047F.
       AB048              AB48_49F.
       AB049              AB48_49F.
       AB050              AB050F.
       AB051              AB051F.
       AB052              AB052F.
       AB053              AB53_68F.
       AB054              AB53_68F.
       AB055              AB53_68F.
       AB056              AB53_68F.
       AB057              AB53_68F.
       AB058              AB53_68F.
       AB059              AB53_68F.
       AB060              AB53_68F.
       AB061              AB53_68F.
       AB062              AB53_68F.
       AB063              AB53_68F.
       AB064              AB53_68F.
       AB065              AB53_68F.
       AB066              AB53_68F.
       AB067              AB53_68F.
       AB068              AB53_68F.
       wvarstrr           3.
   ;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 8 THEN  edad_ac = .M;

   IF  sexo = 9 THEN  sexo = .S;
   IF  edad_ac = 9 THEN  edad_ac = .S;


   ARRAY perdidos1(68)
                   AB001 AB002 AB003 AB004 AB005 AB006 AB007 AB008 AB009 AB010
                   AB011 AB012 AB013 AB014 AB015 AB016 AB017 AB018 AB019 AB020
                   AB021 AB022 AB023 AB024 AB025 AB026 AB027 AB028 AB029 AB030
                   AB031 AB032 AB033 AB034 AB035 AB036 AB037 AB038 AB039 AB040
                   AB041 AB042 AB043 AB044 AB045 AB046 AB047 AB048 AB049 AB050
                   AB051 AB052 AB053 AB054 AB055 AB056 AB057 AB058 AB059 AB060
                   AB061 AB062 AB063 AB064 AB065 AB066 AB067 AB068;
   DO  i=1 TO 68;
          IF perdidos1{i} = 8   THEN  perdidos1{i} = .M;
          IF perdidos1{i} = 9   THEN  perdidos1{i} = .S;
   END;

   drop i;
RUN;
